-- Main.lua
-- Written by Almagnus1

-- IOF Changelog:
-- 2011/06/01  1.0.0 - Final Release - GUI added
-- 2011/05/23  B.1.0 - Beta release - Added various components needed to support the UI
-- 2011/05/23  B.0.0 - Beta release - internal reorganization, completed emote table
-- 2011/05/18  A.0.0 - Alpha release.

import "Almagnus1.IOF";

-- initialize managers
_emotes = EmoteManager();
_settings = SettingManager();
_settings:Load();

-- intialize GUI
_iofGUI = IOFWindow( _settings, _emotes );

-- initialize command parser
iofCommand = Turbine.ShellCommand();

function iofCommand:Execute( command, argument )
	local arguments = string.lower( argument );
	if ( arguments == "help" ) then
		Turbine.Shell.WriteLine( "To show the IOF GUI, type: /iof show" );
		Turbine.Shell.WriteLine( "To hide the IOF GUI, close the window, or type: /iof hide" );
		Turbine.Shell.WriteLine(
			"To hide the IOF GUI if visible, or show the IOF GUI if hidden, type: /iof toggle");
		Turbine.Shell.WriteLine( "Target the door in IOF, then type: /iof <riddle number>" );
		Turbine.Shell.WriteLine( "Expected riddle numbers are between 1 and 83 inclusive." );
		Turbine.Shell.WriteLine( "Ex: /iof 42" );
	--[[
	elseif (arguments == "debug" ) then
		for x = 1, 83, 1 do
			Turbine.Shell.WriteLine( x .. " = \"" .. _emotes:GetEmote( x ) .. "\"");
		end
	--]]	
	elseif ( arguments == "toggle" ) then
		_iofGUI:SetVisibility( not _iofGUI:IsVisible() );
	elseif ( arguments == "show" ) then
		_iofGUI:SetVisibility( true );
	elseif ( arguments == "hide" ) then
		_iofGUI:SetVisibility( false );
	elseif ( tonumber(arguments) ~= nil ) then
		local riddleNum = tonumber(arguments);
		if
			( ( math.floor(riddleNum) == riddleNum ) and
			( ( 1 <= riddleNum ) and ( riddleNum <= 83 ) ) )
		then
			local emote = _emotes:GetEmote( riddleNum );
			if (emote == "" ) then
				Turbine.Shell.WriteLine( "The answer to riddle #" .. riddleNum .. " is not known");
			else
				Turbine.Shell.WriteLine( "Answer to riddle #" .. riddleNum.. ": /" .. emote );
			end
		else
			Turbine.Shell.WriteLine(
				"The riddle number must be an integer between 1 and 83 inclusive." );
		end
	else
		Turbine.Shell.WriteLine(
			"IOF does not recoginze the command \"" ..
			arguments .. 
			"\".  Type \"/iof help\" for more information" );
	end
end

Turbine.Shell.AddCommand( "iof", iofCommand );

Turbine.Shell.WriteLine( "IOF v1.0.0 by Almagnus1" );
