-- SettingManager.lua
-- Written by Almagnus1
-- Serializes/Deserializes settings for IOF's UI

import "Turbine";
import "Turbine.UI";

SettingManager = class( Turbine.Object );

function SettingManager:Constructor()
	-- create setting datastructure with default values
	self.Settings = {};
	self.Settings.Location = {};
	-- defaults to the middle of the screen
	self.Settings.Location.X = 3* Turbine.UI.Display:GetWidth() / 4;
	self.Settings.Location.Y = Turbine.UI.Display:GetHeight() / 3;
	self.Settings.Version = "1.0.0"; -- current version
	self.Settings.Visible = true;
end

function SettingManager:Load()
	local settings = Turbine.PluginData.Load( Turbine.DataScope.Character, "IOFSettings" );
	local width = Turbine.UI.Display:GetWidth();
	local height = Turbine.UI.Display:GetHeight();
	
	if ( ( type( settings ) == "table" )
		and ( type( settings.Location ) == "table" )
		and ( type( settings.Location.X ) == "number" )
		and ( settings.Location.X < width )
		and ( type( settings.Location.Y ) == "number" )
		and ( settings.Location.Y < height )
		and ( ( 76 + settings.Location.X ) <= ( width + 1 ) )
		and ( ( 45 + settings.Location.Y ) <= ( height + 1 ) )
		and ( type( settings.Version ) == "string" )
		and ( type( settings.Visible ) == "boolean" ) )
	then
		self.Settings.Location.X = settings.Location.X;
		self.Settings.Location.Y = settings.Location.Y;
		self.Settings.Visible = settings.Visible;
	end
end

function SettingManager:Save()
	Turbine.PluginData.Save( Turbine.DataScope.Character, "IOFSettings", self.Settings );
end
